@@ -1,17 +1,14 @@
 #!/usr/bin/env python3
-import pathlib
-import click
 import os
-import shutil
+
+import click
 
 from SimEnvControl.libsimenv.repo_path import create_repo
-from .libsimenv.autocomplete import complete_path
-from .libsimenv.sysroots_db import set_dir_readonly_ugo
-from .libsimenv.utils import fatal, warning
+from .libsimenv.utils import fatal
 
 
 @click.command()
-@click.argument("new-repo-root", type=click.Path(exists=False), autocompletion=complete_path)
+@click.argument("new-repo-root", type=click.Path(exists=False))
 def init(new_repo_root):
     """
     Create an empty app repository.
